#  Copyright (c) 2024- Le Filament (https://le-filament.com)
#  License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class EventQuestionAnswer(models.Model):
    _inherit = "event.question.answer"

    number_max = fields.Integer(
        "Nombre maximum autorisé",
        default=0,
        help="Laisser 0 pour ne pas limiter le nombre de fois "
        "où cette réponse pourra être sélectionnée",
    )
    registration_answer_ids = fields.One2many(
        string="Réponses enregistrées",
        comodel_name="event.registration.answer",
        inverse_name="value_answer_id",
    )
    answer_number = fields.Integer(
        "Nombre de réponses enregistrées",
        compute="_compute_answers",
        readonly=True,
    )
    remaining_number = fields.Integer(
        "Nombre de réponses restantes",
        compute="_compute_answers",
        readonly=True,
    )
    fully_booked = fields.Boolean("Complet", compute="_compute_answers", readonly=True)

    @api.depends("number_max", "registration_answer_ids")
    def _compute_answers(self):
        for answer in self:
            answer.answer_number = len(answer.sudo().registration_answer_ids)
            if answer.number_max > 0:
                answer.remaining_number = answer.number_max - answer.answer_number
                answer.fully_booked = answer.remaining_number < 1
            else:
                answer.remaining_number = 0
                answer.fully_booked = False
